@@ -160,6 +160,7 @@ class Users(_defaults_.Defaults):
 		password=None,
 		name=None,
 		superuser=False,
+		activated=True,
 	):
 		# check arguments.
 		response = dev0s.response.parameters.check(
@@ -175,7 +176,8 @@ class Users(_defaults_.Defaults):
 
 			django_user = DjangoUser.objects.create_user(username, email, password)
 			if isinstance(name, str): django_user.last_name = name
-			if isinstance(superuser, bool): django_user.is_superuser = superuser
+			if isinstance(superuser, (bool,Boolean)): django_user.is_superuser = bool(superuser)
+			if isinstance(activated, (bool,Boolean)): django_user.is_active = bool(activated)
 			django_user.save()
 
 			# success.
@@ -195,6 +197,7 @@ class Users(_defaults_.Defaults):
 		password=None,
 		name=None,
 		superuser=None,
+		activated=None,
 	):
 		# check arguments.
 		response = dev0s.response.parameters.check(
@@ -218,9 +221,12 @@ class Users(_defaults_.Defaults):
 			if email != None: 
 				edits += 1
 				django_user.email = email
-			if isinstance(superuser, bool): 
+			if isinstance(superuser, (bool, Boolean)): 
 				edits += 1
-				django_user.is_superuser = superuser
+				django_user.is_superuser = bool(superuser)
+			if isinstance(activated, (bool, Boolean)):
+				edits += 1
+				django_user.is_active = bool(activated)
 			if password != None: 
 				edits += 1
 				django_user.set_password(password)
