@@ -71,6 +71,7 @@ class Users(_defaults_.Defaults):
 			},
 			# the permissions.
 			"permissions": {
+				"activated":False,
 				"email":True,
 			},
 			# timestamps.
@@ -115,6 +116,7 @@ class Users(_defaults_.Defaults):
 		verify_password=None,
 		name=None,
 		superuser=False,
+		activated=True,
 	):
 
 		# check parameters.
@@ -142,7 +144,8 @@ class Users(_defaults_.Defaults):
 				username=username,
 				password=password,
 				name=name,
-				superuser=superuser,)
+				superuser=superuser,
+				activate=activated,)
 			if not response.success: return response
 			user = response.user
 		else:
@@ -171,6 +174,7 @@ class Users(_defaults_.Defaults):
 		data["account"]["email"] = email
 		data["account"]["name"] = name
 		data["account"]["password"] = _response_["encrypted"].decode()
+		data["permissions"]["activated"] = activated
 		print("Saving data...")
 		response = self.save_data(email=email, username=username, data=data)
 		if not response.success: return response
@@ -202,7 +206,7 @@ class Users(_defaults_.Defaults):
 		superuser=None,
 		#phone_number=None,
 		#photo_url=None,
-		#email_verified=None,
+		activated=None,
 	):
 
 		# checks.
@@ -235,7 +239,8 @@ class Users(_defaults_.Defaults):
 			username=username,
 			password=password,
 			name=name,
-			superuser=superuser,)
+			superuser=superuser,
+			activated=activated,)
 		if not response.success: return response
 
 		# update firestore.
@@ -248,6 +253,9 @@ class Users(_defaults_.Defaults):
 		if name != None:
 			edits += 1
 			data["account"]["name"] = name
+		if isinstance(activated, (bool, Boolean)):
+			edits += 1
+			data["permissions"]["activated"] = bool(name)
 		if edits > 0:
 			response = self.save_data(email=email, username=username, data=data)
 			if not response.success: return response
